Check Functions
===============

.. toctree::
    :maxdepth: 2

NWBFile Metadata
----------------
.. automodule:: nwbinspector.checks._nwbfile_metadata

General
-------
.. automodule:: nwbinspector.checks._general

NWB Containers
--------------
.. automodule:: nwbinspector.checks._nwb_containers

Time Series
-----------
.. automodule:: nwbinspector.checks._time_series

Tables
------
.. automodule:: nwbinspector.checks._tables

Behavior
--------
.. automodule:: nwbinspector.checks._behavior

Intracellular Electrophysiology (icephys)
-----------------------------------------
.. automodule:: nwbinspector.checks._icephys

Extracellular Electrophysiology (ecephys)
-----------------------------------------
.. automodule:: nwbinspector.checks._ecephys

Optical Electrophysiology (ophys)
---------------------------------
.. automodule:: nwbinspector.checks._ophys

Optogenetics (ogen)
-------------------
.. automodule:: nwbinspector.checks._ogen

ImageSeries
-----------
.. automodule:: nwbinspector.checks._image_series

Images
------
.. automodule:: nwbinspector.checks._images
